==> haskell-tamarin-prover-export-1.10.0-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-IOy4G4Iv4kt9iUmPDmgA0L
key:                  tamarin-prover-export-1.10.0-IOy4G4Iv4kt9iUmPDmgA0L
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  527c5272023431d72bdf863d2f61b002
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-IOy4G4Iv4kt9iUmPDmgA0L
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-9mqnTxLt4kE4LJjOPDWORv
    tamarin-prover-term-1.10.0-Dsro1ypAgZiCv4mUmqrneS
    tamarin-prover-theory-1.10.0-HAvtF3N9k5HJetasX6rAwu
    tamarin-prover-utils-1.10.0-AnDbdJpsGNdDOUv3PD87ub text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-export-1.10.0-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-CTHexz5yj4hFfzAFIKlmNP
key:                  tamarin-prover-export-1.10.0-CTHexz5yj4hFfzAFIKlmNP
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  7ed5a24e00c400d8a645ed525f749886
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-CTHexz5yj4hFfzAFIKlmNP
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-IQqrXnyvdwhBcXz5iLPMZ6
    tamarin-prover-term-1.10.0-JBUuLi6ad1wGizuxOf3geX
    tamarin-prover-theory-1.10.0-GAqlp4VxdRt233WnhAJzfT
    tamarin-prover-utils-1.10.0-KegB8iQu0YkGYjq48w99kc text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
